<?php
/**
 * Title: Option initializer
 *
 * Description: Initializes theme option. Adds all required files for it.
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Load options customizer file
add_action( 'init', 'ifeature_cc_load_customizer' );
function ifeature_cc_load_customizer() {
	require_once get_parent_theme_file_path( '/cyberchimps/options/options-customizer.php' );
}

function ifeature_cc_get_fields() {
	$fields_list = array();

	// pull in both default fields and users custom fields
	return apply_filters( 'ifeature_cc_field_list', $fields_list );
}

/**
 * Format Configuration Array.
 *
 * Get an array of all default values as set in
 * options.php. The 'id','std' and 'type' keys need
 * to be defined in the configuration array. In the
 * event that these keys are not present the option
 * will not be included in this function's output.
 *
 * @return    array     Rey-keyed options configuration array.
 *
 * @access    private
 */
function ifeature_cc_get_default_values() {
	$output = array();
	$ifeature_cc_config = ifeature_cc_get_fields();
	foreach ( (array) $ifeature_cc_config as $option ) {
		if ( ! isset( $option['id'] ) ) {
			continue;
		}
		if ( ! isset( $option['std'] ) ) {
			continue;
		}
		if ( ! isset( $option['type'] ) ) {
			continue;
		}
		if ( has_filter( 'ifeature_cc_sanitize_' . $option['type'] ) ) {
			$output[ $option['id'] ] = apply_filters( 'ifeature_cc_sanitize_' . $option['type'], $option['std'], $option );
		}
	}

	return $output;
}

/** Sticky Header */
add_action( 'wp_footer', 'ifeature_cc_fixed_menu_onscroll' );
function ifeature_cc_fixed_menu_onscroll() {
	if ( Ifeature_Helper::ifeature_cc_get_option( 'sticky_header', 'checked' ) ) {

		?>
		<script type="text/javascript">
		jQuery(document).ready(function($){
			$(window).scroll(function()  {
			if ($(this).scrollTop() > 0) {
			$('#header_section').addClass("sticky-header");

			}
			else{
			$('#header_section').removeClass("sticky-header");

			}
			});
		});
		</script>
		<?php
	}
}
